@@ -1,10 +1,11 @@
 import requests
 import os
 import os.path
-import sys
 import urllib
 import tempfile
 
+from roktools import logger
+
 from . import AuthenticationError, API_URL, API_KEY_ENV_NAME, SECRET_TOKEN_ENV_NAME
 
 def status(platform, app_version, api_key=None, secret_token=None):
@@ -35,16 +36,32 @@ def status(platform, app_version, api_key=None, secret_token=None):
 
 def submit_process(rover_file, process_type="GNSS", 
                     base_file=None, base_lonlathgt=None,
-                    api_key=None, secret_token=None):
+                    api_key=None, secret_token=None, rover_dynamics='dynamic',
+                    strategy=None, label="jason-gnss"):
     """
     Submit a process to Jason PaaS
+
+    :param rover_file: Filename with the GNSS measurements of the rover receiver
+    :param process_type: Type of process to submit to Jason (GNSS or CONVERSION)
+    :param base_file: Filename with the GNSS measurements of the base receiver
+    :param base_lonlathgt: Array with the longitude, latitude and height
+    :param api_key: Jason API key, if not provided will be fetched from the 
+                    environement variables
+    :param secret_token: Your Jason user secret token, if not provided will be 
+                    fetched from the environement variables
+    :param strategy: Force processing strategy (e.g. PPP or PPK). If left to None
+                    Jason will work on a best effort basis, trying to pick
+                    the most accurate strategy given the data provided by the
+                    user.
+    :param rover_dynamics: Dynamics of the rover receiver ('static' or 'dynamic')
+    :param label: specify a label for the process to submit
     """
 
     if not os.path.isfile(rover_file):
-        sys.stderr.write("Rover file [ {} ] does not exist!".format(rover_file))
+        logger.critical("Rover file [ {} ] does not exist!".format(rover_file))
         return None, None
     elif base_file and not os.path.isfile(base_file):
-        sys.stderr.write("Base file [ {} ] specified but does not exist!".format(base_file))
+        logger.critical("Base file [ {} ] specified but does not exist!".format(base_file))
         return None, None
 
     rover_file_fh = open(rover_file, 'rb')
@@ -59,7 +76,9 @@ def submit_process(rover_file, process_type="GNSS",
     files = {
         'type' : (None, process_type),
         'token' : (None, secret_token),
-        'rover_file': (rover_file, rover_file_fh)
+        'rover_file': (rover_file, rover_file_fh),
+        'rover_dynamics': (None, rover_dynamics),
+        'label': (None, label)
     }
 
     if base_file:
@@ -69,6 +88,11 @@ def submit_process(rover_file, process_type="GNSS",
     if config_file:
         files.update({'config_file' : ('config_file', config_file_fh)})
 
+    if strategy:
+        files.update({'user_strategy' : (None, strategy)})
+
+    logger.debug('Query parameters {}'.format(files))
+
     r = requests.post(url, headers=headers, files=files)
 
     rover_file_fh.close()
@@ -85,6 +109,8 @@ def get_status(process_id, api_key=None, secret_token=None):
     Check the status of a specific process_id
     """
 
+    __check_process_id__(process_id)
+    
     api_key, secret_token = __fetch_credentials__(api_key, secret_token)
 
     url='{}/processes/{}'.format(API_URL, process_id)
@@ -111,11 +137,13 @@ def download_results(process_id, api_key=None, secret_token=None):
     if status['process']['status'] != 'FINISHED':
         return None
 
-    ZIP_FILE_POS = -1
-    url = status['results'][ZIP_FILE_POS]['url']
-    results_file_name = os.path.join(os.getcwd(), status['results'][ZIP_FILE_POS]['name'])
+    zip_result = list(filter(lambda x: (x['type'] == 'zip'), status['results']))[0]
 
+    url = zip_result["value"]
     r = requests.get(url)
+
+    basename = zip_result["name"]
+    results_file_name = os.path.join(os.getcwd(), basename)
     f = open(results_file_name, 'wb')
     f.write(r.content)
     f.close()
@@ -174,6 +202,9 @@ def __fetch_credentials__(api_key, secret_token):
     if secret_token is None:
         secret_token = os.getenv(SECRET_TOKEN_ENV_NAME, secret_token)
 
+    if api_key is None or secret_token is None:
+        raise AuthenticationError("Missing Api key and/or secret token\n")
+
     return api_key, secret_token
 
 def __create_config_file__(base_lonlathgt=None):
@@ -196,4 +227,15 @@ def __create_config_file__(base_lonlathgt=None):
 
     fh = open(name, 'r')
 
-    return name, fh
\ No newline at end of file
+    return name, fh
+
+def __check_process_id__(process_id):
+
+    import re
+
+    process_id_str = str(process_id)
+    pattern = re.compile('[0-9]')
+    result = pattern.findall(process_id_str)
+
+    if len(result) != len(process_id_str):
+        raise ValueError('Process ID [ {} ] does not seem correct, only numbers are allowed\n'.format(process_id_str))
